# Utility bill scraper

[![build](https://github.com/ryanfobel/utility-bill-scraper/actions/workflows/build.yml/badge.svg?branch=main)](https://github.com/ryanfobel/utility-bill-scraper/actions/workflows/build.yml)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/ryanfobel/utility-bill-scraper/main)
[![PyPI version shields.io](https://img.shields.io/pypi/v/utility-bill-scraper.svg)](https://pypi.python.org/pypi/utility-bill-scraper/)

Extract energy usage and carbon footprint from utility websites or pdf bills. Currently, this library supports:

 * [Kitchener Utilities (gas & water)](https://www.kitchenerutilities.ca)
 * [Kitchener-Wilmot Hydro (electricity)](https://www.kwhydro.on.ca)

# Install

```
pip install utility-bill-scraper
```